@@ -5,19 +5,13 @@ import gym
 import numpy as np
 import torch as T
 
-from pearll.agents import A2C, DDPG, DQN, ES, GA, PPO
-from pearll.agents.cem_rl import CEM_RL
+from pearll.agents import A2C, CEM_RL, DDPG, DQN, ES, GA, PPO, AdamES
 from pearll.buffers import HERBuffer
 from pearll.common.utils import get_space_shape
 from pearll.models import ActorCritic, Critic, Dummy, EpsilonGreedyActor
 from pearll.models.actor_critics import Actor
 from pearll.models.encoders import DictEncoder, IdentityEncoder
-from pearll.models.heads import (
-    CategoricalHead,
-    DeterministicHead,
-    DiagGaussianHead,
-    DiscreteQHead,
-)
+from pearll.models.heads import CategoricalHead, DiscreteQHead
 from pearll.models.torsos import MLP
 from pearll.settings import (
     BufferSettings,
@@ -27,6 +21,22 @@ from pearll.settings import (
 )
 
 
+class Sphere(gym.Env):
+    """
+    Sphere(2) function for testing ES agent.
+    """
+
+    def __init__(self):
+        self.action_space = gym.spaces.Box(low=-100, high=100, shape=(2,))
+        self.observation_space = gym.spaces.Discrete(1)
+
+    def step(self, action):
+        return 0, -(action[0] ** 2 + action[1] ** 2), False, {}
+
+    def reset(self):
+        return 0
+
+
 def dqn_demo():
     env = gym.make("CartPole-v0")
     agent = DQN(
@@ -38,7 +48,7 @@ def dqn_demo():
         explorer_settings=ExplorerSettings(start_steps=1000),
     )
     agent.fit(
-        num_steps=50000, batch_size=32, critic_epochs=16, train_frequency=("episode", 1)
+        num_steps=20000, batch_size=32, critic_epochs=16, train_frequency=("episode", 1)
     )
 
 
@@ -72,7 +82,7 @@ def dqn_parallel_demo():
         explorer_settings=ExplorerSettings(start_steps=1000),
     )
     agent.fit(
-        num_steps=50000,
+        num_steps=20000,
         batch_size=32,
         critic_epochs=16,
         train_frequency=("episode", 1),
@@ -97,21 +107,6 @@ def ddpg_demo():
 
 
 def es_demo():
-    class Sphere(gym.Env):
-        """
-        Sphere(2) function for testing ES agent.
-        """
-
-        def __init__(self):
-            self.action_space = gym.spaces.Box(low=-100, high=100, shape=(2,))
-            self.observation_space = gym.spaces.Discrete(1)
-
-        def step(self, action):
-            return 0, -(action[0] ** 2 + action[1] ** 2), False, {}
-
-        def reset(self):
-            return 0
-
     POPULATION_SIZE = 10
     env = gym.vector.SyncVectorEnv([lambda: Sphere() for _ in range(POPULATION_SIZE)])
     actor = Dummy(space=env.single_action_space, state=np.array([10, 10]))
@@ -477,7 +472,7 @@ def a2c_demo():
         logger_settings=LoggerSettings(
             tensorboard_log_path="runs/A2C-demo", verbose=True
         ),
-        entropy_coefficient=0,
+        entropy_coeff=0,
     )
 
     agent.fit(
@@ -499,7 +494,7 @@ def ppo_demo():
         logger_settings=LoggerSettings(
             tensorboard_log_path="runs/PPO-demo", verbose=True
         ),
-        entropy_coefficient=0,
+        entropy_coeff=0,
     )
 
     agent.fit(
@@ -526,7 +521,7 @@ def cem_ddpg_demo():
     )
 
     agent.fit(
-        num_steps=100000,
+        num_steps=50000,
         batch_size=64,
         actor_epochs=1,
         critic_epochs=8,
@@ -534,6 +529,31 @@ def cem_ddpg_demo():
     )
 
 
+def adames_demo():
+    POPULATION_SIZE = 10
+    env = gym.vector.SyncVectorEnv([lambda: Sphere() for _ in range(POPULATION_SIZE)])
+    actor = Dummy(space=env.single_action_space, state=np.array([10, 10]))
+    critic = Dummy(space=env.single_action_space, state=np.array([10, 10]))
+
+    model = ActorCritic(
+        actor=actor,
+        critic=critic,
+        population_settings=PopulationSettings(
+            actor_population_size=env.num_envs, actor_distribution="normal"
+        ),
+    )
+
+    agent = AdamES(
+        env=env,
+        model=model,
+        learning_rate=1,
+        logger_settings=LoggerSettings(
+            tensorboard_log_path="runs/AdamES-demo", log_frequency=("step", 1)
+        ),
+    )
+    agent.fit(num_steps=20, batch_size=1)
+
+
 if __name__ == "__main__":
     parser = ArgumentParser(description="pearll demo with preloaded hyperparameters")
     parser.add_argument("--agent", help="Agent to demo")
@@ -559,5 +579,7 @@ if __name__ == "__main__":
         ppo_demo()
     elif kwargs.agent.lower() == "cem-ddpg":
         cem_ddpg_demo()
+    elif kwargs.agent.lower() == "adames":
+        adames_demo()
     else:
         raise ValueError(f"Agent {kwargs.agent} not found")
